VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "clsFtpFunctions"
Attribute VB_GlobalNameSpace = True
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True


Option Explicit

Dim iErrorCode      As Long
Dim sErrorDesc      As String

Enum TransferType
    FTP_TRANSFER_TYPE_BINARY = &H2
    FTP_TRANSFER_TYPE_ASCII = &H1
End Enum

'*******************************************************************************
'  Function Name            Connect
'  Input Parameters         sServerName,sUserName,sPassword
'  Output parameters        None
'  Return Values            Long
'  Description              Connect to FTP Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function Connect(ByVal sServerName As String, ByVal sUserName As String, _
                        ByVal sPassWord As String) As Long
                        
    On Error GoTo ErrorHandeler
    Dim iConnHandel    As Long
     
    'Create Session
    hOpen = InternetOpen(scUserAgent, INTERNET_OPEN_TYPE_DIRECT, vbNullString, vbNullString, 0)
    
    If hOpen = 0 Then
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
        
    'Connect To Server
    If hOpen <> 0 Then
        iConnHandel = InternetConnect(hOpen, sServerName, INTERNET_INVALID_PORT_NUMBER, _
                                sUserName, sPassWord, INTERNET_SERVICE_FTP, 0, 0)
        If iConnHandel = 0 Then
            iErrorCode = Err.LastDllError
            sErrorDesc = TranslateErrorCode(Err.LastDllError)
        End If
        Connect = iConnHandel
    End If
    
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            DisConnect
'  Input Parameters         hConnectHandel
'  Output parameters        None
'  Return Values            True/False
'  Description              DisConnect from FTP Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function DisConnect(ByVal hConnectHandel As Long) As Boolean
On Error GoTo ErrorHandeler
    DisConnect = False
    
    'Close FTP Handel
    InternetCloseHandle (hConnectHandel)
    
    'Close Session Handel
    InternetCloseHandle (hOpen)
    
    DisConnect = True
    Exit Function
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            PutFile
'  Input Parameters         hConnectHandel,sSourcePath,sSourceFileName,
'                            sDestPath , lTransferType
'  Output parameters        None
'  Return Values            True/False
'  Description              Put a file into Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function PutFile(ByVal hConnectHandel As Long, ByVal sSourcepath As String, _
                        ByVal sSourceFileName As String, Optional ByVal sDestPath As String = "\", _
                        Optional ByVal lTransferType As TransferType = FTP_TRANSFER_TYPE_BINARY) As Boolean
                        
    On Error GoTo ErrorHandeler
    
    Dim sSourceFileWithPath     As String
    Dim sDestFileWithPath       As String
    Dim bRet                    As Boolean
    
    
    PutFile = False
    
    sSourceFileWithPath = sSourcepath & "\" & sSourceFileName
    sDestFileWithPath = sDestPath & "\" & sSourceFileName
    
    bRet = FtpPutFile(hConnectHandel, sSourceFileWithPath, sDestFileWithPath, lTransferType, 0)
    
    If bRet Then
        PutFile = True
    Else
         iErrorCode = Err.LastDllError
         sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
    
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            GetFile
'  Input Parameters         hConnectHandel,sSourcePath,sSourceFileName,
'                           sDestPath , lTransferType
'  Output parameters        None
'  Return Values            True/False
'  Description              Get a file from FTP Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function GetFile(ByVal hConnectHandel As Long, ByVal sSourcepath As String, _
                        ByVal sSourceFileName As String, Optional ByVal sDestPath As String = "\", _
                        Optional sExtension As String = "", _
                        Optional ByVal lTransferType As TransferType = FTP_TRANSFER_TYPE_BINARY) As Boolean
                        
    On Error GoTo ErrorHandeler
    Dim sSourceFileWithPath       As String
    Dim sDestFileWithPath         As String
    Dim bRet                      As Boolean
    
    GetFile = False
    
    sSourceFileWithPath = sSourcepath & sSourceFileName
    sDestFileWithPath = sDestPath & "\" & _
                        IIf(sExtension = "", sSourceFileName, Mid$(sSourceFileName, 1, InStr(sSourceFileName, ".")) & sExtension)
    
    bRet = FtpGetFile(hConnectHandel, sSourceFileWithPath, sDestFileWithPath, False, _
                    INTERNET_FLAG_RESYNCHRONIZE, lTransferType, 0)
    If bRet Then
        GetFile = True
    Else
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
    Exit Function
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            DeleteFile
'  Input Parameters         hConnectHandel, sFileName, sDestPath
'  Output parameters        None
'  Return Values            True/False
'  Description              Delete a file from Server
'  Author                   Sumeet Ahuja
'*******************************************************************************

Public Function DeleteFile(ByVal hConnectHandel As Long, ByVal sFileName As String, _
                            Optional ByVal sDestPath As String = "\") As Boolean
                        
    On Error GoTo ErrorHandeler
    
    Dim sDestFileWithPath         As String
    Dim bRet                      As Boolean
    
    DeleteFile = False
    
    sDestFileWithPath = sDestPath & sFileName
    
    bRet = FtpDeleteFile(hConnectHandel, sDestFileWithPath)
    If bRet Then
        DeleteFile = True
    Else
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
    
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            RenameFile
'  Input Parameters         hConnectHandel,sPath,sOldFileNAme,sNewFileName
'  Output parameters        None
'  Return Values            True/False
'  Description              Rename a file on FTP Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function RenameFile(ByVal hConnectHandel As Long, ByVal sPath As String, _
                            ByVal sOldFileName As String, ByVal sNewFileName As String) As Boolean
                        
    On Error GoTo ErrorHandeler
    
    Dim sOldFileWithPath            As String
    Dim sNewFileWithPath            As String
    Dim bRet                        As Boolean
    
    RenameFile = False
    
    sOldFileWithPath = sPath & "\" & sOldFileName
    sNewFileWithPath = sPath & "\" & sNewFileName
    
    bRet = FtpRenameFile(hConnectHandel, sOldFileWithPath, sNewFileWithPath)
    
    If bRet Then
        RenameFile = True
    Else
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
    
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            CreateDir
'  Input Parameters         hConnectHandel,sPath,sDirName
'  Output parameters        None
'  Return Values            True/False
'  Description              Create a directory on FTP Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function CreateDir(ByVal hConnectHandel As Long, ByVal sPath As String, _
                            ByVal sDirName As String) As Boolean
                        
    On Error GoTo ErrorHandeler
    
    Dim sNewDirName         As String
    Dim bRet                As Boolean
    
    CreateDir = False
    
    sNewDirName = sPath & "\" & sDirName
    
    bRet = FtpCreateDirectory(hConnectHandel, sNewDirName)
    
    If bRet Then
        CreateDir = True
    Else
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
    
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            SetCurrDir
'  Input Parameters         hConnectHandel,sAbsPath
'  Output parameters        None
'  Return Values            True/False
'  Description              Change directory on FTP Server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function SetCurrDir(ByVal hConnectHandel As Long, ByVal sAbsPath As String) As Boolean
                        
    On Error GoTo ErrorHandeler
    Dim bRet            As String
    
    SetCurrDir = False
    
    bRet = FtpSetCurrentDirectory(hConnectHandel, sAbsPath)
    
    If bRet Then
        SetCurrDir = True
    Else
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
    End If
        
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

'*******************************************************************************
'  Function Name            FindFile
'  Input Parameters         hConnectHandel,sAbsPath,sFileName
'  Output parameters        None
'  Return Values            True/False
'  Description              Find First File on the specified Dir on server
'  Author                   Sumeet Ahuja
'*******************************************************************************
Public Function FindFile(ByVal hConnectHandel As Long, ByVal sPath As String, _
                         ByVal sFileName As String, ByRef sRetFileName As String) As Boolean
     On Error GoTo ErrorHandeler
    
    Dim hFind       As Long
    Dim sSerchFile  As String
    Dim pData As WIN32_FIND_DATA

    FindFile = False
    
    sSerchFile = sPath & sFileName
    sRetFileName = ""
    
    hFind = FtpFindFirstFile(hConnectHandel, sSerchFile, pData, ByVal INTERNET_FLAG_RELOAD, 0) ', INTERNET_FLAG_RESYNCHRONIZE
    
    If hFind <> 0 Then
        sRetFileName = Mid$(pData.cFileName, 1, InStr(1, pData.cFileName, vbNullChar) - 1)
        FindFile = True
    Else
        iErrorCode = Err.LastDllError
        sErrorDesc = TranslateErrorCode(Err.LastDllError)
        Debug.Print sErrorDesc
    End If
    InternetCloseHandle (hFind)
    
    Exit Function
    
ErrorHandeler:
    iErrorCode = Err.Number
    sErrorDesc = Err.Description
End Function

Public Property Get LastErrCode() As Long
    LastErrCode = iErrorCode
End Property

Public Property Get LastErrDesc() As String
    LastErrDesc = sErrorDesc
End Property

